"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.blogUpdateResultParser = exports.blogUpdateParamsParser = exports.blogUpdateInputParser = exports.blogCreateOutputParser = exports.blogCreateInputParser = exports.blogAdminsTraitParser = exports.makeBlogAdminsParser = exports.makeBlogAdminsTraitParser = exports.blogAdminParser = exports.blogDeleteParamsParser = exports.blogGetOneResultParser = exports.blogGetOneParamsParser = exports.blogIdParser = exports.blogListResultParser = exports.blogListQueryParser = exports.blogBeneficiaryTraitParser = void 0;
const zod_1 = require("zod");
const parsers_1 = require("../user/parsers");
const utils_1 = require("../channel/utils");
const parsers_2 = require("../channel/parsers");
const parsers_3 = require("../common/parsers");
const parsers_4 = require("../paypal/parsers");
const parsers_5 = require("../stripe/parsers");
const id_utils_1 = require("./id.utils");
const queryParams_1 = require("../common/parsers/queryParams");
const paypalPlanIdOrNull = parsers_4.paypalPlanIdParser.or(zod_1.z.null());
const paypalProductIdOrNull = parsers_4.paypalProductIdParser.or(zod_1.z.null());
exports.blogBeneficiaryTraitParser = zod_1.z.object({
    admins: zod_1.z.array(parsers_1.userIdParser),
});
exports.blogListQueryParser = queryParams_1.firestoreListParamsParser;
exports.blogListResultParser = zod_1.z.array(zod_1.z.any( /*stub*/)).transform((a) => a);
exports.blogIdParser = zod_1.z.string().refine(id_utils_1.isBlogId);
exports.blogGetOneParamsParser = zod_1.z.object({
    id: exports.blogIdParser,
});
exports.blogGetOneResultParser = zod_1.z.any( /*stub, not schemable*/).transform((b) => b);
exports.blogDeleteParamsParser = exports.blogGetOneParamsParser;
exports.blogAdminParser = zod_1.z.string(); // TODO make sense of what we store here
const makeBlogAdminsTraitParser = (a) => zod_1.z.object({
    admins: a,
});
exports.makeBlogAdminsTraitParser = makeBlogAdminsTraitParser;
const makeBlogAdminsParser = (p) => zod_1.z.array(p);
exports.makeBlogAdminsParser = makeBlogAdminsParser;
exports.blogAdminsTraitParser = (0, exports.makeBlogAdminsTraitParser)((0, exports.makeBlogAdminsParser)(exports.blogAdminParser));
exports.blogCreateInputParser = zod_1.z
    .object({
    aboutArtist: zod_1.z.string(),
    artist: zod_1.z.string(),
    artistPicSmall: parsers_3.nullableUrlStringParser,
    artistPicURL: parsers_3.nullableUrlStringParser,
    //I think only one artist has beneficiaries, which is an object described as {NAME: image_link}. Not validating for now
    // beneficiaries:
    beneficiaryAccepted: parsers_3.nullableBoolParser,
    //collectiveSubscribers seem to all be an object with x amt of keys that each have a value of an empty list []. Will have to custom validate this,TODO
    // collectiveSubscribers:
    communityPage: parsers_3.nullableBoolParser,
    coverPicSmall: parsers_3.nullableUrlStringParser,
    coverPicURL: parsers_3.nullableUrlStringParser,
    coverPicURLSmall: parsers_3.nullableUrlStringParser,
    coverResolutions: zod_1.z.object({
        small320: parsers_3.nullableUrlStringParser,
        small800: parsers_3.nullableUrlStringParser,
        small1280: parsers_3.nullableUrlStringParser,
        small1600: parsers_3.nullableUrlStringParser,
        small2000: parsers_3.nullableUrlStringParser,
    }),
    coverSmall: parsers_3.nullableUrlStringParser,
    curatorAlpha: parsers_3.nullableBoolParser,
    createdAllowReminder: parsers_3.nullableBoolParser,
    customlink: parsers_3.nullableUrlStringParser,
    description: parsers_3.nullableStringParser,
    emailNewSubscribers: parsers_3.nullableBoolParser,
    emailSettings: zod_1.z.object({
        reminderTwo: parsers_3.nullableBoolParser,
        newSub: parsers_3.nullableBoolParser,
        reminderThree: parsers_3.nullableBoolParser,
        reminderFour: parsers_3.nullableBoolParser,
        emailNewSubscriber: parsers_3.nullableBoolParser,
        emailNewSubscriberCollective: parsers_3.nullableBoolParser,
    }),
    featuredArtists: zod_1.z.array(zod_1.z.string().refine((id) => (0, utils_1.isChannelId)(id))).default([]),
    founder: zod_1.z.union([zod_1.z.boolean(), zod_1.z.null()]).default(null),
    freetier: zod_1.z.boolean().default(true),
    frequency: zod_1.z.string().default('0'),
    launchDraft: parsers_3.nullableStringParser,
    launched: zod_1.z.boolean().default(false),
    linkTitles: zod_1.z.array(zod_1.z.string()).default([]),
    //TODO: linkViews needs to be a computed value/not validated on creation
    // linkViews: z.array(z.number().default(0)),
    links: zod_1.z.array(zod_1.z.string().url()).default([]),
    paypal: parsers_3.nullableBoolParser,
    'paypal_plan_2.5': paypalPlanIdOrNull,
    paypal_plan_5: paypalPlanIdOrNull,
    paypal_plan_10: paypalPlanIdOrNull,
    paypal_product_id: paypalProductIdOrNull,
    posts: zod_1.z.array(parsers_2.channelIdParser).default([]),
    price: zod_1.z.union([zod_1.z.number(), zod_1.z.null()]).default(null),
    profileResolutions: zod_1.z.object({
        small64: parsers_3.nullableUrlStringParser,
        small128: parsers_3.nullableUrlStringParser,
        small256: parsers_3.nullableUrlStringParser,
        small480: parsers_3.nullableUrlStringParser,
    }),
    reminderLaunchSent: parsers_3.nullableBoolParser,
    reverseTitle: parsers_3.nullableBoolParser,
    scheduled: parsers_3.nullableBoolParser,
    show: parsers_3.nullableStringParser,
    //TODO: ensure we are never overiding with custom ids. shouldnt be the case. Also, worth verifying this with a function that checks with stripe... maybe
    stripeProductID: parsers_5.stripeProductIdParser,
    subscribers: zod_1.z.array(parsers_2.channelIdParser).default([]),
    tipButton: parsers_3.nullableBoolParser,
    title: zod_1.z.string().default('currents'),
    verified: zod_1.z.boolean().default(false),
})
    .merge(exports.blogBeneficiaryTraitParser);
exports.blogCreateOutputParser = exports.blogIdParser;
exports.blogUpdateInputParser = exports.blogCreateInputParser.partial();
exports.blogUpdateParamsParser = exports.blogGetOneParamsParser;
exports.blogUpdateResultParser = zod_1.z.void();
