"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paymentMethodListLimitParser = exports.paymentMethodLimitParser = exports.paymentMethodCompositeKeyParamsParser = exports.paypalPaymentMethodOriginIdParser = exports.stripePamentMethodOriginIdParser = void 0;
const zod_1 = require("zod");
const routes_constant_1 = require("./routes.constant");
const parsers_1 = require("../stripe/parsers");
const queryParams_1 = require("../common/parsers/queryParams");
exports.stripePamentMethodOriginIdParser = zod_1.z.object({
    [routes_constant_1.PAYMENT_METHOD_ORIGIN_ID_PARAM_NAME]: parsers_1.stripePaymentMethodIdParser,
    [routes_constant_1.PAYMENT_METHOD_ORIGIN_TYPE_PARAM_NAME]: zod_1.z.literal('stripe'),
});
exports.paypalPaymentMethodOriginIdParser = zod_1.z.object({
    [routes_constant_1.PAYMENT_METHOD_ORIGIN_ID_PARAM_NAME]: zod_1.z.string(),
    [routes_constant_1.PAYMENT_METHOD_ORIGIN_TYPE_PARAM_NAME]: zod_1.z.literal('paypal'),
});
// TODO may become different for payin/payout if origins become different
exports.paymentMethodCompositeKeyParamsParser = zod_1.z.discriminatedUnion(routes_constant_1.PAYMENT_METHOD_ORIGIN_TYPE_PARAM_NAME, [
    exports.stripePamentMethodOriginIdParser,
    exports.paypalPaymentMethodOriginIdParser,
]);
exports.paymentMethodLimitParser = zod_1.z
    .number()
    .min(0)
    .max(100 /*stripe max but don't expose stripe vars here*/)
    .default(10 /*stripe default limit but don't expose stripe vars here*/);
exports.paymentMethodListLimitParser = (0, queryParams_1.makeLimitParser)(exports.paymentMethodLimitParser);
